# PyPackIT-Test1 © 2024 Armin Ariamajd
# SPDX-License-Identifier: MIT

"""Exceptions raised by the package."""


class PackageError(Exception):
    """Base class for all exceptions raised by this package."""
